@@ -141,7 +141,11 @@ def cli():
 
     Install requirements for trainer
     ================================
-    dsf-cli install_trainer_packages
+    dsf-cli install-trainer-packages
+
+    Install documentation doxygen
+    =============================
+    dsf-cli install-documentation-requirements
     """
 # @click.option("--type", prompt="type", help="type of component")
 # @click.option("--project_name", prompt="project_name", help="project_name")
@@ -409,6 +413,7 @@ def evaluate(csv_file_path, batch_size):
 
 @cli.command()
 def show_documentation():
+    """! Opens a browser and show the local project documentation."""
     launch_doc_webbrowser()
 
 
@@ -648,10 +653,9 @@ def create_folders(project_name):
     create_main_folders('test_schema', 'tester')
     create_main_folders('dsp', 'tester')
     create_main_folders('trainer', 'main')
-    create_main_folders('examples', 'trainer')
-    create_main_folders('datasets', 'trainer')
-    create_main_folders('my_dataset_name', 'datasets')
-    create_main_folders(datetime.today().strftime('%Y%m%d_v1'), 'my_dataset_name')
+    create_main_folders('training_output', 'trainer')
+    create_main_folders('pl_wrapper', 'trainer')
+    create_main_folders('examples', 'pl_wrapper')
     create_main_folders('server', 'main')
 
 
@@ -693,14 +697,23 @@ def create_project(project_name):
     create_dsp_file(original_project_name, directories['dsp'], 'add_experiment', False)
 
     # Create trainer files
-    create_trainer_file(project_name, directories['trainer'], 'custom_dataset', False)
-    create_trainer_file(project_name, directories['trainer'], 'data_module', False)
-    create_trainer_file(project_name, directories['trainer'], 'iterable_dataset', False)
+    create_trainer_file(project_name, directories['pl_wrapper'], 'custom_dataset', False, from_folder='pl_wrapper')
+    create_trainer_file(project_name, directories['pl_wrapper'], 'data_module', False, from_folder='pl_wrapper')
+    create_trainer_file(project_name, directories['pl_wrapper'], 'iterable_dataset', False, from_folder='pl_wrapper')
+    create_trainer_file(project_name, directories['pl_wrapper'], 'plmodel', False, from_folder='pl_wrapper')
+    create_trainer_file(project_name, directories['pl_wrapper'], 'network_module', False, from_folder='pl_wrapper')
+    create_trainer_file(project_name, directories['pl_wrapper'], 'trainer', False, from_folder='pl_wrapper')
+    create_trainer_file(project_name, directories['examples'], 'example1_mnist', False,
+                        from_folder=os.path.join('pl_wrapper', 'examples'))
+    create_trainer_file(project_name, directories['examples'], 'example2_wine_quality', False,
+                        from_folder=os.path.join('pl_wrapper', 'examples'))
+    create_trainer_file(project_name, directories['trainer'], 'comparison', False)
+    create_trainer_file(project_name, directories['trainer'], 'config', False)
+    create_trainer_file(project_name, directories['trainer'], 'data', False)
     create_trainer_file(project_name, directories['trainer'], 'model', False)
-    create_trainer_file(project_name, directories['trainer'], 'network_module', False)
-    create_trainer_file(project_name, directories['trainer'], 'trainer', False)
-    create_trainer_file(project_name, directories['examples'], 'example1_mnist', False, True)
-    create_trainer_file(project_name, directories['examples'], 'example2_wine_quality', False, True)
+    create_trainer_file(project_name, directories['trainer'], 'test', False)
+    create_trainer_file(project_name, directories['trainer'], 'train', False)
+    create_trainer_file(project_name, directories['trainer'], 'trainer_main', False)
     source_path = os.path.join(__location__, 'dsframework/cli/trainer/requirements_trainer.txt')
     shutil.copyfile(source_path, directories['trainer'] + '/requirements_trainer.txt')
 
@@ -797,7 +810,7 @@ def create_tester_file(project_name, folder, test_file_type, createInitFile=True
     replace_in_template_and_create_file(project_name, folder, test_file_type, data, createInitFile)
 
 
-def create_trainer_file(project_name, folder, test_file_type, createInitFile=True, examples_file=False):
+def create_trainer_file(project_name, to_folder, test_file_type, createInitFile=True, from_folder=''):
     """! Create trainer file (read the template and use him to create the new file)
     @verbatim
     Args:
@@ -807,11 +820,10 @@ def create_trainer_file(project_name, folder, test_file_type, createInitFile=Tru
         createInitFile(=True): Create init file - if it doesn't exist.
     @endverbatim
     """
-    if not examples_file:
-        data = read_template_file('trainer/' + test_file_type)
-    else:
-        data = read_template_file('trainer/examples/' + test_file_type)
-    replace_in_template_and_create_file(project_name, folder, test_file_type, data, createInitFile)
+
+    # data = read_template_file('trainer/' + test_file_type)
+    data = read_template_file(os.path.join('trainer', from_folder, test_file_type))
+    replace_in_template_and_create_file(project_name, to_folder, test_file_type, data, createInitFile)
 
 
 def create_dsp_file(project_name, folder, test_file_type, createInitFile=True):
@@ -1315,9 +1327,6 @@ def copy_batch_files(main_dir):
     source_dir = os.path.join(__location__, 'dsframework/cli/tester/batch_files/')
 
     for (dir_path, dir_name, filenames) in os.walk(source_dir):
-        if "__pycache__" in dir_path:
-            continue
-
         dir_path = dir_path.replace(source_dir, '')
         file_list = [os.path.join(dir_path, file) for file in filenames]
         for file_path in file_list:
@@ -1420,7 +1429,7 @@ def copy_documentation_files(target_dir):
         target_dir: Newly created project location
     """
     source_dir = os.path.join(__location__, 'dsframework/documentation/')
-    shutil.copytree(source_dir, target_dir, ignore=shutil.ignore_patterns('dsf*'))
+    shutil.copytree(source_dir, target_dir, ignore=shutil.ignore_patterns('dsf_doxy*'))
 
 
 def update_doc_configuration(project_name, target_dir):
@@ -1439,10 +1448,51 @@ def update_doc_configuration(project_name, target_dir):
 
 @cli.command()
 def install_trainer_packages():
+    """! Install trainer packages."""
     command = 'pip install -r trainer/requirements_trainer.txt'
     subprocess.call(command, shell=True)
 
 
+@cli.command()
+def install_documentation_requirements():
+    """! Install documentation doxygen."""
+
+    doxygen_found = True
+
+    try:  # Check for brew installation
+        command = 'brew -v'
+        res = subprocess.check_output(command, shell=True)
+        brew_found = 'Homebrew' in str(res)
+
+        if brew_found:
+            try:  # Check for doxygen installation (if brew found)
+                command = 'brew ls --versions doxygen'
+                res = subprocess.check_output(command, shell=True)
+                doxygen_found = 'doxygen' in str(res)
+
+                if doxygen_found:
+                    print('Doxygen already installed.')
+
+            except subprocess.CalledProcessError as e1:
+                doxygen_found = False
+
+    except subprocess.CalledProcessError as e2:
+        brew_found = False
+
+    if not doxygen_found or not brew_found:
+        installation_file = os.path.join(os.path.dirname(os.path.realpath(__file__)), 'dsframework', 'documentation',
+                                         'install_doxygen.sh')
+        if not os.path.exists(installation_file):
+            print('Installation script not found install_doxygen.sh')
+            return
+        is_mac_linux = (platform.system() == 'Darwin' or platform.system() == 'Linux')
+
+        if is_mac_linux:
+            subprocess.call(f'chmod +x {installation_file}', shell=True)
+
+        subprocess.call(installation_file, shell=True)
+
+
 def to_capitalize_no_underscore(text):
     """! Capitalize each word with no underscore
      for example : Moving from test_name -> TestName"""
