@@ -1,10 +1,26 @@
 #!/usr/bin/env python
 # coding: utf-8
-"""
-This file hold all regular expressions used in the project.
-We declare the pattern and compile them for better performance.
-We wrap each regex / group of regexes with functions as API
-"""
+
+##
+# @file
+# @brief This file hold all regular expressions used in the project.
+#        We declare the pattern and compile them for better performance.
+#        We wrap each regex / group of regexes with functions as API
+#        For example RegexHandler.url2.findall(text) -> find all urls in the text
+#        in the background we use
+#        RegexHandler.url2 = re.compile(url_pattern2)
+#        url_pattern2 = r"(?i)\b((?:https?://|www\d{0,3}[.]|[a-z0-9.\-]+[.][a-z]{2,4}/)(?:[^\s()<>]+|\(([^\s()<>]+|(\([^\s()<>]+\)))*\))+(?:\(([^\s()<>]+|(\([^\s()<>]+\)))*\)|[^\s`!()\[\]{};:'\".,<>?«»“”‘’]))"
+#
+#        Another example with emojis:
+#        ----------------------------
+#        we define:
+#        emoji_pattern = u'([\U00002600-\U000027BF])|([\U0001f300-\U0001f64F])|([\U0001f680-\U0001f6FF])'
+#        emoji = re.compile(emoji_pattern, flags=re.UNICODE)
+#        and then we can use:
+#        emojis = RegexHandler.emoji.findall(t)  // -> in order to find emojis
+#        or
+#        return RegexHandler.emoji.sub(r'', t)  // -> in order to remove all emojis from text
+
 import datetime
 import math
 import re
@@ -21,7 +37,9 @@ class RegexHandler:
 
     url_pattern = r'''(?i)\b((?:[a-z][\w-]+:(?:/{1,3}|[a-z0-9%])|www\d{0,3}[.]|[a-z0-9.\-]+[.][a-z]{2,4}/)(?:[^\s()<>]+|\(([^\s()<>]+|(\([^\s()<>]+\)))*\))+(?:\(([^\s()<>]+|(\([^\s()<>]+\)))*\)|[^\s`!()\[\]{};:'".,<>?«»“”‘’]))'''
     url_pattern2 = r"(?i)\b((?:https?://|www\d{0,3}[.]|[a-z0-9.\-]+[.][a-z]{2,4}/)(?:[^\s()<>]+|\(([^\s()<>]+|(\([^\s()<>]+\)))*\))+(?:\(([^\s()<>]+|(\([^\s()<>]+\)))*\)|[^\s`!()\[\]{};:'\".,<>?«»“”‘’]))"
-    email_pattern = r'([\w\.-]+@[\w\.-]+\.\w+)'
+    ## For example 36 steps , 0.1ms  (https://www.example.com/)
+    url_pattern3 = r"((http|https):\/\/)(www.)?[a-zA-Z0-9@:%._\\+~#?&\/\/=]{2,256}\.[a-z]{2,6}([-a-zA-Z0-9@:%._\\+~#?&\/\/=]*)"
+    email_pattern = r"([\w\.-]{1,256}@[\w\.-]{1,256}\.\w{1,256})"
     emoji_pattern = u'([\U00002600-\U000027BF])|([\U0001f300-\U0001f64F])|([\U0001f680-\U0001f6FF])'
     number_pattern = r'\d+'
     join_spaces_pattern = r' {2,}'
@@ -105,6 +123,7 @@ class RegexHandler:
 
     url = re.compile(url_pattern)
     url2 = re.compile(url_pattern2)
+    url3 = re.compile(url_pattern3)
     email = re.compile(email_pattern)
     emoji = re.compile(emoji_pattern, flags=re.UNICODE)
     number = re.compile(number_pattern)
@@ -533,6 +552,14 @@ class RegexHandler:
 
     @staticmethod
     def get_number_of_digits_in_number(n):
+        """! This function return the number of digits in number
+         @verbatim
+         Args:
+            n : Number
+         Returns:
+            digits: # of digits in the number.
+         @endverbatim
+         """
         if n == '':
             return 0
         if type(n) is str:
@@ -617,10 +644,26 @@ class RegexHandler:
 
     @staticmethod
     def is_time_format(t):
+        """! Is time format is valid
+          @verbatim
+          Args:
+             t : time
+          Returns:
+             bool : TRUE if time match the format
+          @endverbatim
+        """
         return bool(RegexHandler.time.match(t))
 
     @staticmethod 
     def has_time_format(t):
+        """! Has time format.
+          @verbatim
+          Args:
+             t : time
+          Returns:
+             bool : if input t, has the time format correctly - > return True.
+          @endverbatim
+        """
         t = t.lower().replace('am', ' ').replace('pm', ' ')
         r_list = RegexHandler.has_time.findall(t)
         if not len(r_list):
@@ -635,6 +678,14 @@ class RegexHandler:
 
     @staticmethod
     def remove_html(t):
+        """! Removing HTML template.
+          @verbatim
+          Args:
+             t : text
+          Returns:
+             string : without html template
+          @endverbatim
+        """
         return RegexHandler.html.sub(r'', t)
 
     @staticmethod
@@ -648,6 +699,14 @@ class RegexHandler:
 
     @staticmethod
     def merge_multiple_new_lines(t):
+        """! Merge multiple new lines.
+          @verbatim
+          Args:
+             t : Text
+          Returns:
+             new text : merged lines (removed the \n ).
+          @endverbatim
+          """
         return RegexHandler.merge_lines.sub('\n', t).strip()
 
     @staticmethod
@@ -762,10 +821,26 @@ class RegexHandler:
 
     @staticmethod
     def is_bad_decoding_line(line):
+        """! Return if this line has bad decoding.
+        @verbatim
+        Args:
+           line : Line
+        Returns:
+           bool : True if this line has bad decoding.
+        @endverbatim
+        """
         return len(re.findall(RegexHandler.bad_decoding, line, flags=0)) > 0
 
     @staticmethod
     def contain_date(tt):
+        """! Check if the text contains date.
+        @verbatim
+        Args:
+           tt : text we want to check if it's date.
+        Returns:
+           bool : True if contain date.
+        @endverbatim
+        """
         def remove_punct(s):
             return " ".join(s.translate(str.maketrans('', '', string.punctuation)).split()).strip()
     
@@ -792,6 +867,15 @@ class RegexHandler:
 
     @staticmethod
     def extract_emojies_codes(input_string, check_first=True):
+        """! Remove duplicates lines.
+        @verbatim
+        Args:
+           input_string : String
+           check_first(=True): Check input string if contains an emoji.
+        Returns:
+            returnString, emojies, ascies
+        @endverbatim
+        """
         if check_first:
             if not RegexHandler.contain_emoji(input_string):
                 return input_string
