@@ -119,8 +119,8 @@ if __name__ == "__main__":
             stage.update_stage_params(start_date, end_date, params)
             stage.main()
         except Exception as e:
-            raise Exception(f" Stage failed with error: {e}")
+            print(f" Stage failed with error: {e}")
     else:
-        raise Exception(f"Stage configuration not provided, Can't run stage")
+        print(f"Stage configuration not provided, Can't run stage")
 
 
