@@ -5,11 +5,17 @@ UNIMPLEMENTED_ERROR_MESSAGE = "Please override the parent base class methods for
 
 
 class CloudEvalClient(CloudEvalClientBase):
+    """Parent class of CloudEvalClientBase, override this class methods for using cloud eval with your project."""
+
     def __init__(self):
+        """CloudEvalClient initializer.
+
+        Instantiate generatedProjectNameEvaluator()
+        """
+
+        ## Instance of generatedProjectNameEvaluator()
         self.model_evaluator = generatedProjectNameEvaluator()
-    """
-    Override the parent base class methods for using cloud eval
-    """
+
     def get_request_headers(self, row: dict):
         raise NotImplementedError(UNIMPLEMENTED_ERROR_MESSAGE)
 
